<?php

namespace App\Http\Controllers;

use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\View\View;
use Illuminate\Support\Facades\DB;
use App\Models\User;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Hash;


class DashboardController extends Controller
{
    public function __construct()
    {
        
    }
    /**
     * Display the user's profile form.
     */
    public function index(Request $request)
    {
        $user_role = Auth::user()->role; 
        if($user_role !== 'admin')
        {
            return Redirect::to('/login');
        }

		$user_list_result = DB::table('users')                     
                    ->select('*',  DB::RAW("DATE_FORMAT(created_at, '%d-%b-%Y') AS added_on"))
                    ->where('role','user')
                    ->orderBy('id')
                    ->get(); 
        $user_list = array();
        foreach($user_list_result as $index=>$row)
        {
            $member_id = $row->affilliate_member_id;
            $member_name = "";
            if(!empty($member_id))
            {
                $member_name = DB::table('users')->where('id',$member_id)->pluck('name')->first();   
            }
            $user_list[] = array('data'=>$row, 'member_name'=> $member_name);
            
        }
      
        return view('admin_dashboard', compact('user_list'));
    }

    public function affilliateMembers(Request $request)
    {
        $user_role = Auth::user()->role; 
        if($user_role !== 'admin')
        {
            return Redirect::to('/login');
        }

		$user_list = DB::table('users')->select('*',DB::RAW("DATE_FORMAT(created_at, '%d-%b-%Y') AS added_on"))
                ->where('role','member')
                ->where('is_active','1')
                ->orderBy('id')
                ->get(); 
		
        return view('admin_members', compact('user_list'));
    }

    public function addMember(Request $request)
    {

        $random_code = Str::random(10);

        $user_role = Auth::user()->role; 
        if($user_role !== 'admin')
        {
            return Redirect::to('/login');
        }

        return view('add_member', compact('random_code'));
    }

    public function editMember($user_id="")
    {
        $user_role = Auth::user()->role; 
        if($user_role !== 'admin')
        {
            return Redirect::to('/login');
        }

        $user_data =  User::where("id",$user_id)->first();

        return view('edit_member', compact('user_data'));
    }

    public function saveMember(Request $request)
    {
        $validatorData = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'lowercase', 'email', 'max:100', 'unique:'.User::class],           
            'contact_number' => ['required','min:6', 'max:15', 'unique:'.User::class],
            'password' => ['required','min:6'],
            'password_confirmation' => 'required|same:password',
            'affilliate_code' => ['required','min:10' , 'unique:'.User::class],
           
        ]);
     
        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'contact_number' => $request->contact_number,
            'password' => Hash::make($request->password),
            'role'  => 'member',
            'affilliate_code' => $request->affilliate_code,
        ]);

        return redirect('affiliate-members');
    }

    public function updateMember(Request $request)
    {
        $user_id = isset($request->hdn_user_id) ? $request->hdn_user_id : "";

        $validatorData = $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|string|lowercase|email|max:100|unique:users,email,'.$user_id,           
            'contact_number' => 'required|min:6|max:15|unique:users,contact_number,'.$user_id,
            'affilliate_code' => 'required|min:10|unique:users,affilliate_code,'.$user_id,
           
        ]);
        
        if(!empty($request->password))
        {
            $user = User::updateOrCreate(
                ['id' => $user_id],
                [
                'name' => $request->name,
                'email' => $request->email,
                'contact_number' => $request->contact_number,
                'password' => Hash::make($request->password),                
                'affilliate_code' => $request->affilliate_code,
                ]
            );
        }
        else
        {
            $user = User::updateOrCreate(
                ['id' => $user_id],
                [
                'name' => $request->name,
                'email' => $request->email,
                'contact_number' => $request->contact_number,
                'affilliate_code' => $request->affilliate_code,
                ]
            );

        }
        

        return redirect('affiliate-members');
    }

    public function update_payment($user_id="")
    {
        if(!empty($user_id))
        {
            DB::table('users')->where('id',$user_id)->update(['payment_status'=>'C']);
        }

        return redirect('admin-dashboard');
   
    }

    public function deleteMember($user_id="")
    {
        if(!empty($user_id))
        {
            DB::table('users')->where('id',$user_id)->update(['is_active'=>'0']);
        }

        return redirect('affiliate-members');
   
    }


    
}
